Class: ShopifyAPI::Event
- Inherits:
-
Base
- Object
- ActiveResource::Base
- Base
- ShopifyAPI::Event
- Includes:
- DisablePrefixCheck
- Defined in:
- lib/shopify_api/resources/event.rb
Class Method Summary collapse
-
.prefix(options = {}) ⇒ Object
Hack to allow both Shop and other Events in through the same AR class.
Methods inherited from Base
activate_session, clear_session, headers, #persisted?
Methods included from Countable
Methods inherited from ActiveResource::Base
build, delete, #encode, headers
Class Method Details
.prefix(options = {}) ⇒ Object
Hack to allow both Shop and other Events in through the same AR class
8 9 10 |
# File 'lib/shopify_api/resources/event.rb', line 8 def self.prefix(={}) [:resource].nil? ? "/admin/" : "/admin/#{[:resource]}/#{[:resource_id]}/" end |