Class: ShopifyAPI::Asset
- Defined in:
- lib/shopify_api.rb
Overview
Assets represent the files that comprise your theme. There are different buckets which hold different kinds of assets, each corresponding to one of the folders within a theme’s zip file: layout, templates, and assets. The full key of an asset always starts with the bucket name, and the path separator is a forward slash, like layout/theme.liquid or assets/bg-body.gif.
Initialize with a key:
asset = ShopifyAPI::Asset.new(:key => 'assets/special.css')
Find by key:
asset = ShopifyAPI::Asset.find('assets/image.png')
Get the text or binary value:
asset.value # decodes from attachment attribute if necessary
You can provide new data for assets in a few different ways:
* assign text data for the value directly:
asset.value = "div.special {color:red;}"
* provide binary data for the value:
asset.attach(File.read('image.png'))
* set a URL from which Shopify will fetch the value:
asset.src = "http://mysite.com/image.png"
* set a source key of another of your assets from which
the value will be copied:
asset.source_key = "assets/another_image.png"
Class Method Summary collapse
-
.element_path(id, prefix_options = {}, query_options = nil) ⇒ Object
:nodoc:.
-
.find(*args) ⇒ Object
find an asset by key: ShopifyAPI::Asset.find(‘layout/theme.liquid’).
Instance Method Summary collapse
- #attach(data) ⇒ Object
-
#destroy ⇒ Object
:nodoc:.
-
#method_missing(method_symbol, *arguments) ⇒ Object
:nodoc:.
-
#new? ⇒ Boolean
:nodoc:.
-
#value ⇒ Object
For text assets, Shopify returns the data in the ‘value’ attribute.
Methods included from Countable
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(method_symbol, *arguments) ⇒ Object
:nodoc:
462 463 464 465 466 467 |
# File 'lib/shopify_api.rb', line 462 def method_missing(method_symbol, *arguments) #:nodoc: if %w{value= attachment= src= source_key=}.include?(method_symbol) wipe_value_attributes end super end |
Class Method Details
.element_path(id, prefix_options = {}, query_options = nil) ⇒ Object
:nodoc:
457 458 459 460 |
# File 'lib/shopify_api.rb', line 457 def self.element_path(id, = {}, = nil) #:nodoc: , = () if .nil? "#{prefix()}#{collection_name}.#{format.extension}#{query_string()}" end |
.find(*args) ⇒ Object
find an asset by key:
ShopifyAPI::Asset.find('layout/theme.liquid')
427 428 429 430 431 432 433 434 435 |
# File 'lib/shopify_api.rb', line 427 def self.find(*args) if args[0].is_a?(Symbol) super else params = {:asset => {:key => args[0]}} params = params.merge(args[1][:params]) if args[1] && args[1][:params] find(:one, :from => "/admin/assets.#{format.extension}", :params => params) end end |
Instance Method Details
#attach(data) ⇒ Object
445 446 447 |
# File 'lib/shopify_api.rb', line 445 def attach(data) self. = Base64.encode64(data) end |
#destroy ⇒ Object
:nodoc:
449 450 451 |
# File 'lib/shopify_api.rb', line 449 def destroy #:nodoc: connection.delete(element_path(:asset => {:key => key}), self.class.headers) end |
#new? ⇒ Boolean
:nodoc:
453 454 455 |
# File 'lib/shopify_api.rb', line 453 def new? #:nodoc: false end |
#value ⇒ Object
For text assets, Shopify returns the data in the ‘value’ attribute. For binary assets, the data is base-64-encoded and returned in the ‘attachment’ attribute. This accessor returns the data in both cases.
440 441 442 443 |
# File 'lib/shopify_api.rb', line 440 def value attributes['value'] || (attributes['attachment'] ? Base64.decode64(attributes['attachment']) : nil) end |