Class: ShopifyAPI::Event
- Defined in:
- lib/shopify_api.rb
Class Method Summary collapse
-
.prefix(options = {}) ⇒ Object
Hack to allow both Shop and other Events in through the same AR class.
Methods included from Countable
Class Method Details
.prefix(options = {}) ⇒ Object
Hack to allow both Shop and other Events in through the same AR class
386 387 388 |
# File 'lib/shopify_api.rb', line 386 def self.prefix(={}) [:resource].nil? ? "/admin/" : "/admin/#{[:resource]}/#{[:resource_id]}/" end |